import { __assign } from './../external/tslib/tslib.es6.js';
import React, { useState, useRef, useEffect } from 'react';
import { parseMetadata } from '@highlight-ui/utils-commons';
import { Icon } from '@highlight-ui/icon';
import { Panel } from '@highlight-ui/panel';
import { Typography } from '@highlight-ui/typography';
import { pastelPalette, mainPalette } from './palettes.js';
import styles from './ColorPicker.module.scss.js';

var ColorPicker = function (_a) {
  var _b = _a.closeOnSelect,
      closeOnSelect = _b === void 0 ? false : _b,
      disabled = _a.disabled,
      initialColor = _a.initialColor,
      metadata = _a.metadata,
      onChange = _a.onChange,
      _c = _a.palette,
      palette = _c === void 0 ? 'main' : _c,
      title = _a.title;

  var _d = useState(false),
      focused = _d[0],
      setFocused = _d[1];

  var wrapperRef = useRef(null);
  var colorPalette = palette === 'pastel' ? pastelPalette : mainPalette;

  var _e = useState(false),
      isPaletteOpen = _e[0],
      setIsPaletteOpen = _e[1];

  var _f = useState(initialColor === undefined ? colorPalette[0].backgroundColor : initialColor),
      currentColor = _f[0],
      setCurrentColor = _f[1];

  useEffect(function () {
    var onDocumentClick = function (e) {
      if (wrapperRef.current && e.target instanceof Node && !wrapperRef.current.contains(e.target)) {
        setIsPaletteOpen(false);
      }
    };

    window.document.addEventListener('mousedown', onDocumentClick);
    return function () {
      window.document.removeEventListener('mousedown', onDocumentClick);
    };
  }, []);

  var onColorClick = function (selectedColor) {
    onChange(selectedColor);
    setCurrentColor(selectedColor);

    if (closeOnSelect) {
      setIsPaletteOpen(false);
    }
  };

  return /*#__PURE__*/React.createElement("div", {
    className: styles.colorPicker,
    ref: wrapperRef
  }, /*#__PURE__*/React.createElement("button", __assign({}, parseMetadata(metadata), {
    className: styles.button,
    disabled: disabled,
    onClick: function () {
      return setIsPaletteOpen(!isPaletteOpen);
    },
    onFocus: function () {
      return setFocused(true);
    },
    onBlur: function () {
      return setFocused(false);
    },
    type: "button"
  }), /*#__PURE__*/React.createElement("div", {
    className: styles.colorDot,
    "data-test-id": "selected-color",
    style: {
      background: currentColor
    }
  }), /*#__PURE__*/React.createElement(Icon, {
    name: "sort-down",
    type: "solid",
    color: focused ? 'icon-highlight' : 'icon-subdued'
  })), isPaletteOpen && /*#__PURE__*/React.createElement(Panel, {
    className: styles.panel,
    absolute: true
  }, /*#__PURE__*/React.createElement(Typography, {
    variant: "subtitle-2",
    className: styles.title
  }, title), /*#__PURE__*/React.createElement("div", {
    className: styles.optionRow
  }, colorPalette.map(function (_a) {
    var identifier = _a.identifier,
        backgroundColor = _a.backgroundColor,
        highlight = _a.highlight;
    return /*#__PURE__*/React.createElement("div", {
      className: styles.colorOption,
      "aria-label": "select-color-" + identifier,
      key: identifier,
      onClick: function () {
        return onColorClick(backgroundColor);
      },
      onKeyDown: function (e) {
        return e.key === 'Enter' && onColorClick(backgroundColor);
      },
      role: "button",
      style: {
        backgroundColor: backgroundColor,
        color: highlight
      },
      tabIndex: 0
    });
  }))));
};

export { ColorPicker as default };
//# sourceMappingURL=ColorPicker.js.map
